@@ -34,7 +34,7 @@ class Complete():
     # KEEP '#version:' on first line as it it since it is used in
     # sequana/pipeline_common.py right now
     setup = """#version: {version}
-function _mycomplete_()
+function _mycomplete_{pipeline_name}()
 {{
     local cur prev opts
     COMPREPLY=()
@@ -54,7 +54,7 @@ function _mycomplete_()
 
 }}
 #complete -d -X '.[^./]*' -F _mycomplete_ sequana_{pipeline_name}
-complete  -F _mycomplete_ sequana_{pipeline_name}
+complete  -F _mycomplete_{pipeline_name} sequana_{pipeline_name}
     """
 
     def __init__(self, pipeline_name):
@@ -79,6 +79,7 @@ complete  -F _mycomplete_ sequana_{pipeline_name}
 
         with open(output_filename, "w") as fout:
             fout.write(self.setup.format(version=self.pipeline_version,
+                                        pipeline_name=pipeline_name,
                                          options=" ".join(arguments)))
             for action in self._actions:
                 option_name = action.option_strings[0]
@@ -89,7 +90,7 @@ complete  -F _mycomplete_ sequana_{pipeline_name}
                     fout.write(self.set_option_directory(option_name))
                 elif option_name.endswith("-file"):
                     fout.write(self.set_option_file(option_name))
-                elif option_name in ["--databases"]:
+                elif option_name in ["--databases", "--from-project"]:
                     fout.write(self.set_option_directory(option_name))
             fout.write(self.teardown.format(pipeline_name=self.pipeline_name))
 
